@@ -171,9 +171,11 @@ class TestSolveBanded(TestCase):
         assert_raises(ValueError, solve_banded, (1, 1), ab, [1.0, 2.0])
 
     def test_1x1(self):
-        x = solve_banded((1, 1), [[0], [1], [0]], [[1, 2, 3]])
-        assert_array_equal(x, [[1.0, 2.0, 3.0]])
+        b = array([[1., 2., 3.]])
+        x = solve_banded((1, 1), [[0], [2], [0]], b)
+        assert_array_equal(x, [[0.5, 1.0, 1.5]])
         assert_equal(x.dtype, np.dtype('f8'))
+        assert_array_equal(b, [[1.0, 2.0, 3.0]])
 
 
 class TestSolveHBanded(TestCase):
